@@ -1,5 +1,5 @@
 ## File Name: BIFIE.summary.R
-## File Version: 0.15
+## File Version: 0.16
 
 BIFIE.summary <- function(object, print.time=TRUE)
 {
@@ -13,8 +13,7 @@ BIFIE.summary <- function(object, print.time=TRUE)
     cat("'" )
     cat("\n\nCall:\n", paste(deparse(object$CALL), sep="\n", collapse="\n"),
                 "\n\n", sep="")
-    # cat("\n\n")
-    cat( "Date of Analysis:", paste( object$time[2] ), "\n" )
+    cat( "Date of Analysis:", paste( object$time[1] ), "\n" )
     if (print.time){
         cat("Computation time:", print(object$time[2] - object$time[1] ), "\n\n")
     } else {
@@ -28,16 +27,16 @@ BIFIE.summary <- function(object, print.time=TRUE)
         cat("Nested multiply imputed dataset\n\n")
     }
 
-    cat( "Number of persons=", object$N, "\n" )
+    cat( "Number of persons", "=", object$N, "\n" )
     # cat( "Number of imputed datasets=", object$Nimp, "\n" )
     if ( ! object$NMI){
-        cat( "Number of imputed datasets=", object$Nimp, "\n" )
+        cat( "Number of imputed datasets", "=", object$Nimp, "\n" )
     }
     if ( object$NMI){
-        cat( "Number of imputed between-nest datasets=", object$Nimp_NMI[1], "\n" )
-        cat( "Number of imputed within-nest datasets=", object$Nimp_NMI[2], "\n" )
+        cat( "Number of imputed between-nest datasets", "=", object$Nimp_NMI[1], "\n" )
+        cat( "Number of imputed within-nest datasets", "=", object$Nimp_NMI[2], "\n" )
     }
 
-    cat( "Number of Jackknife zones per dataset=", object$RR, "\n" )
+    cat( "Number of Jackknife zones per dataset",  "=", object$RR, "\n" )
     cat( "Fay factor=", round( object$fayfac, 5 ), "\n\n" )
 }
